#
# spec file for package beust-jcommander
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __requires_exclude java-headless
%global short_name jcommander
Name:           beust-%{short_name}
Version:        1.85
Release:        1.1
Summary:        Java framework for parsing command line parameters
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://jcommander.org/
Source0:        %{short_name}-%{version}.tar.xz
# Adapted from earlier version that still shipped poms. It uses kobalt for building now
Source1:        %{name}.pom
Source2:        %{name}-build.xml
Patch0:         0001-ParseValues-NullPointerException-patch.patch
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  java-devel >= 9
BuildRequires:  javapackages-local >= 6
Requires:       java >= 1.8
Obsoletes:      %{short_name} < %{version}-%{release}
Provides:       %{short_name} = %{version}-%{release}
BuildArch:      noarch

%description
JCommander is a Java framework that allows parsing command line
parameters (with annotations).

%package javadoc
Summary:        API documentation for %{name}
Group:          Development/Libraries/Java

%description javadoc
This package contains the %{summary}.

%prep
%setup -q -n %{short_name}-%{version}
%patch -P 0 -p1

chmod -x license.txt
cp -p %{SOURCE1} pom.xml
cp -p %{SOURCE2} build.xml
sed -i 's/@VERSION@/%{version}/g' pom.xml build.xml

%build
%{ant} jar javadoc

%install
# jars
install -d -m 0755 %{buildroot}%{_javadir}
install -m 644 target/%{short_name}-%{version}.jar \
   %{buildroot}%{_javadir}/%{name}.jar

# pom
install -d -m 755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}.pom
%add_maven_depmap %{name}.pom %{name}.jar

# javadoc
install -dm 755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}/%{name}/

%files -f .mfiles
%license license.txt
%doc notice.md README.markdown

%files javadoc
%{_javadocdir}/%{name}

%changelog
* Thu Sep  5 2024 Fridrich Strba <fstrba@suse.com>
- Update to version 1.85
  * Changes of 1.84
    + Changed the method processing to only ignore bridge and
    synthetic methods which are not duplicate of other normal
    methods.
    + Renamed BuilderExample to BridgeMethodsExample.
    + Exclude methods which are bridge or synthetic when parsing
    + Added public IMainParameter interface to fix
    cbeust/jcommander#559
    + Fixed: A default fulfils requirement, but does not count as
    assignment.
    + Expand dynamic arg expands non dynamic args
    + Order parameters with the same order by name in usage()
    + Asserting that double quotes are not removed.
    + Replace arrayOf with array literals in Kotlin sample
    + Keep original exception thrown by the parameter setter method
    + Fixes #557: Now validates BEFORE conversion
    + Fixed: Broken link to TestNG example
    + Allow acceptUnknownOption with variableArity
    + Fixed: Default value of primitive type must not satisfy
    required = true
    + Simplified code: No need for public class
    + No ParameterException if a default value assigned for
    required params
    + Fixed documentation: Contributor fixed inidex.html instead of
    index.adoc
    + Example for @Parameter on setter method
    + Fixed docs formatting
    + Mentioning Charset converter in docs
    + Improved ByteOrderConverterTest: Removing unused Exception
    + Adds a CharsetConverter.
    + Mentioning ByteOrder converter in docs
    + Improved ByteOrderConverterTest: Proofs that parameter may be
    in mixed case
    + Adds a ByteOrderConverter.
    + Improved VariableArityTest: Proofs that unknown options are
    safely passed through
    + Test for dontShowNullForMissingCommandDescription
    + Fix usage() for missing description on commands
    + Moved description of defaultValueDescription to usage chapter
    + Fixed backwards compatiblity fail:
    ParameterDescription.getDefault() must not produce different
    result as existing code relies on current behavior
    + Fixed test fail: NullPointerException in ParameterDescription
    + Fixed #471 @Param(default = )
    + Clarification: List and Set can be comma-separated
    + Modify convertValue() to fix issue 509 and add a test
    + Performance: String.isEmpty() is faster than .equals()
    + Return an empty list when parsing an empty string
    + Using secret GPG_PASSPHRASE for improved security
    + Fixed: Deprecation Warning about new Integer(int)
    + Ignore default value for required parameter
  * Changes of 1.85
    + Fixed: Compilation fails due to Java 11 API used on Java 8
    target
    + Cleanup configFile after enabledAtSignExpansionTest
    + Simplified AtSignExpansion code
    + Improved testing of AtSignExpansion
    + Fix: enable parameter values to start with @
    + Simplified Strings::startsWith
    + Simplified Strings::join(String, List<Object>)
    + Simplified Strings::join(String, List<String>)
- Modified patch:
  * 0001-ParseValues-NullPointerException-patch.patch
    + rebase
* Mon May 20 2024 Fridrich Strba <fstrba@suse.com>
- Update to version 1.83
  * Fixes:
    + Fixed Docs Timestamp
    + Fixed: #563 - JCommander does not recognize command by alias.
    + fixed: missing null check
    + renamed IRule to IParametersValidator
    + `@Parameters(rules = <? extends IRule>)`
    + Unit Test for #532
    + Fixed #532: @-syntax not working with command objects
    + enable testng tests
    + Fix regression with removed usage methods
    + Add OSGi entries in MANIFEST.MF during jar creation
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed May  3 2023 Fridrich Strba <fstrba@suse.com>
- Update to version 1.82
  * Fixes:
    + #392: fixed bug when parsing arguments is ignoring case
    sensitivity option
    + Add a test for Parameter order usage
    + add a test for Path converter
    + Add automatic module name to manifest
    + Add check if Boolean parameter is default null, then do not
    flip value
    + Added testing modules
    + Add format tests for DefaultUsageFormatter,
    UnixStyleUsageFormatter
    + add Path converter change #414 to changelog
    + Add test case for issue 367
    + Add testing for UnixStyleUsageFormatter
    + Add unix-style formatter, allow DefaultUsageFormatter to be
    extended easier
    + Allow generics of type <? extends X> and <? super Y> in
    parameters
    + Allow main parameters to be a single field.
    + allow System.out to be replaced by something else (f.e.
    System.err)
    + Allow UsageFormatter to be set in JCommander Builder
    + Change UsageFormatter into an interface
    + Clean up DefaultUsageFormatter
    + Create MyDelegate.java
    + Create UsageFormatter (preliminary)
    + Enable usage() ordering for DynamicParameter
    + Encapsulate MainParameter.
    + encode user input to massage error message
    + Expose more of the UsageFormatter implementations
    + Fields annotated with @ParametersDelegate are now allowed to
    be final.
    + FIX #380 Main parameter doesn't support Converter
    + Fix error message when failing to convert a Path
    + Fixing: squid:ModifiersOrderCheck and squid:S2444
    + Fix locale-related issues in usage formatter tests
    + Get boolean/Boolean getter with "is" prefix
    + GH-477 Environment Variable Default Provider
    + make console configurable by JCommander.Builder
    + Make UsageFormatter abstract, Create DefaultUsageFormatter
    + Only one DefaultConverterFactory
    + Remove String.join usage - resolves #381
    + Remove the generic in IStringConverterFactory
    + Restrict access to JCommander.Options again
    + Support arity for main parameters.
    + Update DefaultParameterizedParser.java
    + Update IParameterizedParser.java
    + Update JCommander.java
    + usage() hides 'Comments:' header when only hidden commands
    exist
    + Use Builder API as constructor is deprecated
    + Use get<fieldname> default getter approach if is<fieldname>
    method is not found
  * Upgrade needed by new code in xmvn 4.2.0
- Fetch sources using source service and clean the tarball of
  unnecessary binary files
* Mon Apr  8 2019 Fridrich Strba <fstrba@suse.com>
- Remove reference to pom parent from pom.xml file, since we are
  not building with maven.
* Thu Feb  7 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid double shipping of documentation.
- Ensure neutrality of descriptions.
* Thu Dec  6 2018 Fridrich Strba <fstrba@suse.com>
- Fix javadoc build with older JDK versions
* Thu Oct 25 2018 Fridrich Strba <fstrba@suse.com>
- Build with java source/target levels 8 since the code uses
  String.join() which does not exist before java 8
* Wed Oct 24 2018 Fridrich Strba <fstrba@suse.com>
- Initial packaging built without maven, adapted from Fedora rpm
